<?php
/**
  * Version from 1.2.4 of PrestaShop
  * PLUS CHANGES BY THAT SOFTWARE GUY http://www.thatsoftwareguy.com
*/
class BlockInfos extends Module
{
	private $_html;

	public function __construct()
	{
		$this->name = 'blockinfos';
		$this->tab = 'Blocks';
		$this->version = 1.1;

		parent::__construct();

		$this->displayName = $this->l('Info block');
		$this->description = $this->l('Adds a block with several information links');
	}

	public function install()
	{
		if (!parent::install() OR !$this->registerHook('leftColumn'))
			return false;
		Db::getInstance()->Execute('
			INSERT INTO `'._DB_PREFIX_.'block_cms`(`id_block`, `id_cms`)
			VALUES
				('.intval($this->id).', 1),
				('.intval($this->id).', 2),
				('.intval($this->id).', 3),
				('.intval($this->id).', 4)');
		return true;
	}

	public function uninstall()
	{
		Db::getInstance()->Execute('
			DELETE FROM `'._DB_PREFIX_.'block_cms`
			WHERE `id_block` ='.intval($this->id));
		parent::uninstall();
	}

	public function getContent()
	{
		if(isset($_POST['btnSubmit'])) {
			$this->_postValidation();
			if (!sizeof($this->_errors))
				$this->_postProcess();
			else
			{
				foreach ($this->_errors AS $err)
					$this->_html .= '<div class="errmsg">'.$err.'</div>';
			}
		}
		$this-> _displayForm();
		return $this->_html;
	}

	private function _postValidation()
	{
		$this->_errors = array();

		// This should NEVER happen
		$idBox = Tools::getValue('idBox');
		if (!is_array($idBox)) { 
			$this->_errors[] = $this->displayError($this->l('id is required.'));
		} else { 
			foreach ($idBox as $order) {					
				if (!is_numeric($order) || !Validate::isUnsignedInt($order)) {
					$this->_errors[] = $this->displayError($this->l('Id must be numeric.'));
					break;
				}
			} 
		}

		// This will happen if bad values entered in sort order box
		$sortorderBox = Tools::getValue('sortorderBox');
		if (!is_array($sortorderBox)) { 
			$this->_errors[] = $this->displayError($this->l('Sort order is required.'));
		} else { 
			foreach ($sortorderBox as $order) {					
				if (!is_numeric($order) || !Validate::isUnsignedInt($order)) {
					$this->_errors[] = $this->displayError($this->l('Sort order must be numeric.'));
					break;
				}
			} 
		}
	}

	private function _displayForm()
	{
		global $cookie;

		$this->_html .=
		'<form action="'.$_SERVER['REQUEST_URI'].'" method="post">
			<fieldset>
			<legend>'.$this->l('Selected files displayed').'</legend>
					<span>'.$this->l('Please check files that will be displayed in this module').'.</span><br /><br />
					<table cellspacing="0" cellpadding="0" class="table" style="width: 29.5em;">
							<thead>
								<tr>
									<th><input type="checkbox" name="checkme" class="noborder" onclick="checkDelBoxes(this.form, \'categoryBox[]\', this.checked)" /></th>
									<th>'.$this->l('ID').'</th>
									<th>'.$this->l('Sort').'</th>
									<th>'.$this->l('Name').'</th>
								</tr>
							</thead>
							<tbody>';
		$cms = CMS::listCms($cookie->id_lang);
		foreach($cms AS $row) {
			$this->_html .='
				<tr><td><input type="checkbox" class="noborder" value="'.$row['id_cms'].'" name="categoryBox[]" '.((CMS::isInBlock($row['id_cms'], $this->id)) ? 'checked="checked"' : '').'></td><td>'.$row['id_cms'].'</td><td>'.  
				'<input type="text" name="sortorderBox[]" size="5" value="'.
				$row['sort_order'].'" /></td><td>'.
				$row['meta_title'].'</td></tr>';
		$this->_html .='
				<input type="hidden" name="idBox[]" value="' . $row['id_cms']. '" />';
		}
		$this->_html .='
							</tbody>
						</table>
						<br />
						<input type="submit" name="btnSubmit" class="button" value="'.$this->l('Update').'">'; 
		$this->_html .='
			</fieldset>'; 
		$this->_html .='
		</form>';
	}

	private function _postProcess()
	{
		if (Tools::isSubmit('btnSubmit'))
		{
			// Do sort order
			$idBox = Tools::getValue('idBox');
			$sortorderBox = Tools::getValue('sortorderBox');
			$numIds = sizeof($idBox);
			if ( $numIds  == sizeof($sortorderBox) ) 
			{
				if (!CMS::updateCmsSortOrder($idBox, $sortorderBox)) {
					$this->_html .= '<div class="conf confirm">'.$this->l('Error in Cms Update').'</div>';
					return;
				}
			} else {
					$this->_html .= '<div class="conf confirm">'.$this->l('Error in Cms Update - bad count').'</div>';
					return;
			}

			$categoryBox = Tools::getValue('categoryBox');
			if ($categoryBox AND is_array($categoryBox) AND count($categoryBox))
			{
				foreach ($categoryBox AS $row)
					$cms[] = intval($row);
				if (CMS::updateCmsToBlock($cms, $this->id))
					$this->_html .= '<div class="conf confirm">'.$this->l('Cms Updated').'</div>';
			}
			else
			{
				Db::getInstance()->Execute('
				DELETE FROM `'._DB_PREFIX_.'block_cms`
				WHERE `id_block` ='.intval($this->id));
			}
		}
	}

	function hookLeftColumn($params)
	{
		global $smarty, $cookie;

		$cms = CMS::listCms($cookie->id_lang, $this->id);
		$id_cms = array();
		foreach($cms AS $row)
			$id_cms[] = intval($row['id_cms']);
		$smarty->assign('cmslinks', CMS::getLinks($cookie->id_lang, $id_cms ? $id_cms : NULL));
		return $this->display(__FILE__, 'blockinfos.tpl');
	}

	function hookRightColumn($params)
	{
		return $this->hookLeftColumn($params);
	}
}
